app_intents_codegen library
Code generator for Flutter AppIntents.
This library provides code generation utilities for creating Swift and Dart code from @IntentSpec and @EntitySpec annotations.
Classes
- AppShortcutInfo
- Information about an App Shortcut to generate.
- DartGenerator
- Generator for Dart code that registers intent and entity handlers.
- EntityAnalyzer
- Analyzer for extracting entity information from annotated classes.
- EntityInfo
- Represents analyzed information about an entity specification.
- EntityPropertyInfo
- Represents analyzed information about an entity property.
- EnumAnalyzer
- Analyzer for extracting enum information from annotated enums.
- EnumCaseInfo
- Represents a single case of an AppEnum.
- EnumInfo
- Represents analyzed information about an AppEnum specification.
- IntentAnalyzer
- Analyzer for extracting intent information from annotated classes.
- IntentInfo
- Represents analyzed information about an intent specification.
- IntentParamInfo
- Represents analyzed information about an intent parameter.
- KotlinGenerator
- Generates Kotlin code for Android AppFunctions from analyzed Dart specifications.
- ShortcutAnalyzer
- Analyzer for extracting shortcut information from annotated classes.
- SwiftGenerator
- Generates Swift code for iOS AppIntents from analyzed Dart specifications.
Enums
- EntityPropertyRole
- The role of an entity property.
- IntentImplementationType
- The implementation language for the intent.
- IntentModeType
- The execution mode for the intent.